django-nokia
============
[![Build Status](https://travis-ci.org/orcasgit/django-nokia.svg?branch=master)](https://travis-ci.org/orcasgit/django-nokia) [![Coverage Status](https://coveralls.io/repos/orcasgit/django-nokia/badge.png)](https://coveralls.io/r/orcasgit/django-nokia) [![Requirements Status](https://requires.io/github/orcasgit/django-nokia/requirements.png?branch=master)](https://requires.io/github/orcasgit/django-nokia/requirements/?branch=master)

Django-nokia is a Django app for integrating a user's Nokia data into your
site.

It handles the details of getting your app authorized to access your user's
Nokia data via the Nokia Health API.

NOTE: If you are coming from django-withings, there are some
[extra steps](docs/migrate_from_withings.rst) needed to migrate.

Documentation is hosted on <http://django-nokia.readthedocs.org>.
